use std::ffi::c_void;
use std::os::raw::{c_long, c_int};

// Define the `timeval` struct as it is in C.
#[repr(C)]
struct Timeval {
    tv_sec: c_long,   // seconds
    tv_usec: c_long,  // microseconds
}

// Declare the `gettimeofday` function with the correct signature.
// Since we don't need the `timezone` parameter, we can pass a null pointer.
extern "C" {
    fn gettimeofday(tv: *mut Timeval, tz: *mut c_void) -> c_int;
}

pub fn run() {
    // Create an instance of `Timeval` with uninitialized values.
    let mut tv = Timeval {
        tv_sec: 0,
        tv_usec: 0,
    };

    // Call the `gettimeofday` function.
    let ret = unsafe { gettimeofday(&mut tv as *mut Timeval, std::ptr::null_mut()) };

    if ret == 0 {
        println!("Seconds: {}, Microseconds: {}", tv.tv_sec, tv.tv_usec);
    } else {
        eprintln!("Failed to get time");
    }
}