use std::os::raw::{c_int, c_void};

const SIGUSR1: c_int = 30;

// Define the type for a signal handler function in C
type SignalHandler = unsafe extern "C" fn(c_int);

// Declare some libc functions
extern "C" {
    fn signal(signum: c_int, handler: SignalHandler) -> *mut c_void;
    fn raisehi(signum: c_int) -> c_int;
}

// Our Rust signal handler
unsafe extern "C" fn handle_signal(_signum: c_int) {
    // NB: println! in general is not async-signal-safe, see `man signal-safe`
    println!("Caught SIGUSR1!");
}

pub fn run() {
    // Install the signal handler
    unsafe {
        let _previous_handler = signal(SIGUSR1, handle_signal);
    }

    // send SIGUSR1 to the current process
    let result = unsafe { raisehi(SIGUSR1) };

    if result == 0 {
        println!("Signal sent successfully.");
    } else {
        eprintln!("Failed to send signal.");
    }
}
