use std::os::raw::{c_char, c_int};
use std::ffi::CStr;

// Declare the `strerror` function from libc.
extern "C" {
    fn strerror(errnum: c_int) -> *const c_char;
}

pub fn run() {
    // Example error number EAGAIN = 35
    let errnum: c_int = 35;

    // Call `strerror` using an unsafe block since it's an FFI call.
    let c_const_char_ptr = unsafe { strerror(errnum) };

    // Check if the returned pointer is null
    if c_const_char_ptr.is_null() {
        println!("strerror({}) returned null", errnum)
    } else {
        // Convert the C string (null-terminated) to a Rust string.
        let error_message = unsafe { CStr::from_ptr(c_const_char_ptr) }
            .to_str().unwrap(); // check that UTF-8 validation succeeded

        /* */
        let error_message_mut = c_const_char_ptr as *mut c_char;
        unsafe {
            *error_message_mut = 'r' as c_char;
        }
        /* */

        println!("error {} translates into {}", errnum, error_message);
    }
}